# SportScraper
<p align="left">
    <a href="https://pypi.python.org/pypi/sport-scraper">
        <img alt="PyPI Version" src="https://img.shields.io/pypi/v/sport-scraper.svg">
    </a>
 </p>

ESPN.com is a great site for gathering statistics about sports teams at both the college and major league level. This repository provides an easy to use interface for pulling data from the ESPN website. 

## Requirements
* Python 3.6+
* Works on Linux, Windows, macOS, BSD

## Installation
The quick way
```
pip install sport_scraper
```

## Contributing

There are many ways to contribute to SportScraper. Here are some of them:

* Blog about SportScraper. Tell the world how you’re using SportScraper. This will help newcomers with more examples and will help the SportScraper project to increase its visibility.
* Report bugs and request features by emailing us at sportscraperbugs@gmail.com
* Submit patches for new functionalities and/or bug fixes.
* Answer SportScraper questions at Stack Overflow.

## Disclaimer

This library is for educational purposes only. Webscraping of publicly available data was ruled legal by The Ninth Circuit Court of Appeals (http://cdn.ca9.uscourts.gov/datastore/opinions/2019/09/09/17-16783.pdf).

